@@ -10,7 +10,7 @@
 #***********************************************************************************************
 #***********************************************************************************************
 
-linarpt <- function(inc, id = NULL, weight = NULL, sort = NULL, 
+linarpt <- function(Y, id = NULL, weight = NULL, sort = NULL, 
         Dom = NULL, period=NULL, dataset = NULL, percentage = 60,
         order_quant=50, var_name="lin_arpt") {
 
@@ -33,7 +33,7 @@ linarpt <- function(inc, id = NULL, weight = NULL, sort = NULL,
 
    if(!is.null(dataset)) {
        dataset <- data.frame(dataset, stringsAsFactors=FALSE)
-       if (checker(inc, dataset, "inc")) inc <- dataset[, inc] 
+       if (checker(Y, dataset, "Y")) Y <- dataset[, Y] 
 
        if(!is.null(id)) {
           id2 <- id
@@ -62,17 +62,17 @@ linarpt <- function(inc, id = NULL, weight = NULL, sort = NULL,
       }
 
    # check vectors
-   # inc
-   inc <- data.frame(inc)
-   n <- nrow(inc)
-   if (ncol(inc) != 1) stop("'inc' must be a vector or 1 column data.frame, matrix, data.table")
-   inc <- inc[,1]
-   if(!is.numeric(inc)) stop("'inc' must be numerical")
-   if (any(is.na(inc))) stop("'inc' has unknown values")
+   # Y
+   Y <- data.frame(Y)
+   n <- nrow(Y)
+   if (ncol(Y) != 1) stop("'Y' must be a vector or 1 column data.frame, matrix, data.table")
+   Y <- Y[,1]
+   if(!is.numeric(Y)) stop("'Y' must be numerical")
+   if (any(is.na(Y))) stop("'Y' has unknown values")
 
    # weight
    weight <- data.frame(weight)
-   if (nrow(weight) != n) stop("'weight' must be the same length as 'inc'")
+   if (nrow(weight) != n) stop("'weight' must be the same length as 'Y'")
    if (ncol(weight) != 1) stop("'weight' must be vector or 1 column data.frame, matrix, data.table")
    weight <- weight[,1]
    if (!is.numeric(weight)) stop("'weight' must be numerical")
@@ -81,7 +81,7 @@ linarpt <- function(inc, id = NULL, weight = NULL, sort = NULL,
    # sort
    if (!is.null(sort) && !is.vector(sort) && !is.ordered(sort)) {
          stop("'sort' must be a vector or ordered factor") }
-   if (!is.null(sort) && length(sort) != n) stop("'sort' must have the same length as 'inc'")
+   if (!is.null(sort) && length(sort) != n) stop("'sort' must have the same length as 'Y'")
    
    # period     
    if (!is.null(period)) {
@@ -89,7 +89,7 @@ linarpt <- function(inc, id = NULL, weight = NULL, sort = NULL,
        if (any(duplicated(names(period)))) 
                  stop("'period' are duplicate column names: ", 
                       paste(names(period)[duplicated(names(period))], collapse = ","))
-       if (nrow(period) != n) stop("'period' must be the same length as 'inc'")
+       if (nrow(period) != n) stop("'period' must be the same length as 'Y'")
        if(any(is.na(period))) stop("'period' has unknown values")  
    }   
       
@@ -98,7 +98,7 @@ linarpt <- function(inc, id = NULL, weight = NULL, sort = NULL,
    id <- data.table(id)
    if (any(is.na(id))) stop("'id' has unknown values")
    if (ncol(id) != 1) stop("'id' must be 1 column data.frame, matrix, data.table")
-   if (nrow(id) != n) stop("'id' must be the same length as 'inc'")
+   if (nrow(id) != n) stop("'id' must be the same length as 'Y'")
    if (is.null(names(id))||(names(id)=="id")) setnames(id,names(id),"ID")
    if (is.null(period)){ if (any(duplicated(id))) stop("'id' are duplicate values") 
                        } else {
@@ -112,10 +112,10 @@ linarpt <- function(inc, id = NULL, weight = NULL, sort = NULL,
                  stop("'Dom' are duplicate column names: ", 
                       paste(names(Dom)[duplicated(names(Dom))], collapse = ","))
              if (is.null(names(Dom))) stop("'Dom' must be colnames")
-             if (nrow(Dom) != n) stop("'Dom' must be the same length as 'inc'")
+             if (nrow(Dom) != n) stop("'Dom' must be the same length as 'Y'")
+             Dom <- Dom[, lapply(.SD, as.character), .SDcols = names(Dom)]
        }
 
-
     ## computations
     ind0 <- rep.int(1,n)
     period_agg <- period1 <- NULL
@@ -126,7 +126,7 @@ linarpt <- function(inc, id = NULL, weight = NULL, sort = NULL,
 
     # ARPT by domain (if requested)  
 
-    quantile <- incPercentile(inc, weights = weight, sort = sort,
+    quantile <- incPercentile(Y = Y, weights = weight, sort = sort,
                               Dom = Dom, period=period,
                               k = order_quant, dataset = NULL)
     quantile <- data.table(quantile)
@@ -147,7 +147,7 @@ linarpt <- function(inc, id = NULL, weight = NULL, sort = NULL,
         for(i in 1:nrow(Dom_agg)) {
               g <- c(var_name, paste(names(Dom), as.matrix(Dom_agg[i,]), sep = "."))
               var_nams <- do.call(paste, as.list(c(g, sep="__")))
-              ind <- (rowSums(Dom == Dom_agg[i,][ind0,]) == ncol(Dom))
+              ind <- as.integer(rowSums(Dom == Dom_agg[i,][ind0,]) == ncol(Dom))
               arpt_l <- lapply(1:nrow(period1_agg), function(j) {
                                if (!is.null(period)) { 
                                        rown <- cbind(period_agg[j], Dom_agg[i])
@@ -157,7 +157,7 @@ linarpt <- function(inc, id = NULL, weight = NULL, sort = NULL,
                                rown <- merge(rown, quantile, all.x=TRUE)
                                ind2 <- (rowSums(period1 == period1_agg[j,][ind0,]) == ncol(period1))
                                
-                               arptl <- arptlinCalc(inco=inc[ind2], 
+                               arptl <- arptlinCalc(inco=Y[ind2], 
                                                     ids=arpt_id[ind2],
                                                     wght=weight[ind2],
                                                     indicator=ind[ind2], 
@@ -169,7 +169,7 @@ linarpt <- function(inc, id = NULL, weight = NULL, sort = NULL,
              setnames(arptl, names(arptl), c(names(arpt_id), var_nams))
              setkeyv(arpt_m, names(arpt_id))
              setkeyv(arptl, names(arpt_id))
-             arpt_m <- merge(arpt_m, arptl, all.x=T)
+             arpt_m <- merge(arpt_m, arptl, all.x=TRUE)
           }
       } else { arptl <- lapply(1:nrow(period1_agg), function(j) {
                            if (!is.null(period)) { 
@@ -179,7 +179,7 @@ linarpt <- function(inc, id = NULL, weight = NULL, sort = NULL,
                                        } else rown <- quantile
                            ind2 <- (rowSums(period1 == period1_agg[j,][ind0,]) == ncol(period1))
  
-                           arptl <- arptlinCalc(inco=inc[ind2], 
+                           arptl <- arptlinCalc(inco=Y[ind2], 
                                                 ids=arpt_id[ind2],
                                                 wght=weight[ind2],
                                                 indicator=ind0[ind2], 
